@@ -1,4 +1,4 @@
-__version__ = '0.5.1'
+__version__ = '0.5.4'
 
 from yarl import URL
 from distutils.version import StrictVersion
@@ -8,24 +8,8 @@ import aiohttp
 import re
 
 from aioipfs import api
-
-
-class APIError(Exception):
-    """
-    IPFS API error
-
-    :param int code: IPFS error code
-    :param str message: Error message
-    """
-
-    def __init__(self, code=-1, message='', http_status=-1):
-        self.code = code
-        self.message = message
-        self.http_status = http_status
-
-
-class UnknownAPIError(APIError):
-    pass
+from aioipfs.exceptions import *  # noqa
+from aioipfs.apis import pin as pin_api
 
 
 class AsyncIPFS(object):
@@ -43,13 +27,15 @@ class AsyncIPFS(object):
 
     def __init__(self, host='localhost', port=5001, loop=None,
                  conns_max=0, conns_max_per_host=0,
-                 read_timeout=0, api_version='v0'):
+                 read_timeout=0, api_version='v0',
+                 debug=False):
 
         self._conns_max = conns_max
         self._conns_max_per_host = conns_max_per_host
         self._read_timeout = read_timeout
         self._host = host
         self._port = port
+        self._debug = debug
 
         self.loop = loop if loop else asyncio.get_event_loop()
 
@@ -75,7 +61,7 @@ class AsyncIPFS(object):
         self.files = api.FilesAPI(self)
         self.filestore = api.FilestoreAPI(self)
         self.key = api.KeyAPI(self)
-        self.pin = api.PinAPI(self)
+        self.pin = pin_api.PinAPI(self)
         self.log = api.LogAPI(self)
         self.name = api.NameAPI(self)
         self.object = api.ObjectAPI(self)
@@ -87,6 +73,10 @@ class AsyncIPFS(object):
 
         self._agent_version = None
 
+    @property
+    def debug(self):
+        return self._debug
+
     @property
     def agent_version(self):
         return self._agent_version
@@ -119,6 +109,10 @@ class AsyncIPFS(object):
     def get(self):
         return self.core.get
 
+    @property
+    def getgen(self):
+        return self.core.getgen
+
     @property
     def id(self):
         return self.core.id
